==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/statemachine/impl/NoEventTransitionSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.statemachine.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.statemachine.NoEventTransition;
import io.ciera.tool.sql.ooaofooa.statemachine.NoEventTransitionSet;
import io.ciera.tool.sql.ooaofooa.statemachine.StateMachineStateSet;
import io.ciera.tool.sql.ooaofooa.statemachine.TransitionSet;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.StateMachineStateSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.TransitionSetImpl;

import java.util.Arrays;
import java.util.List;


public class NoEventTransitionSetImpl extends InstanceSet<NoEventTransitionSet,NoEventTransition> implements NoEventTransitionSet {

    // attributes
    @Override
    public void setTrans_ID( UniqueId ref_Trans_ID ) throws XtumlException {
        for ( NoEventTransition noeventtransition : this ) noeventtransition.setTrans_ID( ref_Trans_ID );
    }
    @Override
    public void setSMstt_ID( UniqueId ref_SMstt_ID ) throws XtumlException {
        for ( NoEventTransition noeventtransition : this ) noeventtransition.setSMstt_ID( ref_SMstt_ID );
    }
    @Override
    public void setSMspd_IDdeprecated( UniqueId m_SMspd_IDdeprecated ) throws XtumlException {
        for ( NoEventTransition noeventtransition : this ) noeventtransition.setSMspd_IDdeprecated( m_SMspd_IDdeprecated );
    }
    @Override
    public void setSM_ID( UniqueId ref_SM_ID ) throws XtumlException {
        for ( NoEventTransition noeventtransition : this ) noeventtransition.setSM_ID( ref_SM_ID );
    }


    // selections
    @Override
    public TransitionSet R507_is_a_Transition() throws XtumlException {
        TransitionSet transitionset = new TransitionSetImpl();
        for ( NoEventTransition noeventtransition : this ) transitionset.add( noeventtransition.R507_is_a_Transition() );
        return transitionset;
    }
    @Override
    public StateMachineStateSet R508_originates_from_StateMachineState() throws XtumlException {
        StateMachineStateSet statemachinestateset = new StateMachineStateSetImpl();
        for ( NoEventTransition noeventtransition : this ) statemachinestateset.add( noeventtransition.R508_originates_from_StateMachineState() );
        return statemachinestateset;
    }


    @Override
    public NoEventTransition nullElement() {
        return NoEventTransitionImpl.EMPTY_NOEVENTTRANSITION;
    }

    @Override
    public NoEventTransitionSet emptySet() {
      return new NoEventTransitionSetImpl();
    }

    @Override
    public NoEventTransitionSet value() {
        return this;
    }

    @Override
    public List<NoEventTransition> elements() {
        return Arrays.asList(toArray(new NoEventTransition[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/statemachine/impl/NoEventTransitionSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.statemachine.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.statemachine.NoEventTransition;
import io.ciera.tool.sql.ooaofooa.statemachine.NoEventTransitionSet;
import io.ciera.tool.sql.ooaofooa.statemachine.StateMachineStateSet;
import io.ciera.tool.sql.ooaofooa.statemachine.TransitionSet;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.StateMachineStateSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.TransitionSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class NoEventTransitionSetImpl extends InstanceSet<NoEventTransitionSet,NoEventTransition> implements NoEventTransitionSet {

    public NoEventTransitionSetImpl() {
    }

    public NoEventTransitionSetImpl(Comparator<? super NoEventTransition> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setSMspd_IDdeprecated( UniqueId m_SMspd_IDdeprecated ) throws XtumlException {
        for ( NoEventTransition noeventtransition : this ) noeventtransition.setSMspd_IDdeprecated( m_SMspd_IDdeprecated );
    }
    @Override
    public void setTrans_ID( UniqueId ref_Trans_ID ) throws XtumlException {
        for ( NoEventTransition noeventtransition : this ) noeventtransition.setTrans_ID( ref_Trans_ID );
    }
    @Override
    public void setSM_ID( UniqueId ref_SM_ID ) throws XtumlException {
        for ( NoEventTransition noeventtransition : this ) noeventtransition.setSM_ID( ref_SM_ID );
    }
    @Override
    public void setSMstt_ID( UniqueId ref_SMstt_ID ) throws XtumlException {
        for ( NoEventTransition noeventtransition : this ) noeventtransition.setSMstt_ID( ref_SMstt_ID );
    }


    // selections
    @Override
    public TransitionSet R507_is_a_Transition() throws XtumlException {
        TransitionSet transitionset = new TransitionSetImpl();
        for ( NoEventTransition noeventtransition : this ) transitionset.add( noeventtransition.R507_is_a_Transition() );
        return transitionset;
    }
    @Override
    public StateMachineStateSet R508_originates_from_StateMachineState() throws XtumlException {
        StateMachineStateSet statemachinestateset = new StateMachineStateSetImpl();
        for ( NoEventTransition noeventtransition : this ) statemachinestateset.add( noeventtransition.R508_originates_from_StateMachineState() );
        return statemachinestateset;
    }


    @Override
    public NoEventTransition nullElement() {
        return NoEventTransitionImpl.EMPTY_NOEVENTTRANSITION;
    }

    @Override
    public NoEventTransitionSet emptySet() {
      return new NoEventTransitionSetImpl();
    }

    @Override
    public NoEventTransitionSet emptySet(Comparator<? super NoEventTransition> comp) {
      return new NoEventTransitionSetImpl(comp);
    }

    @Override
    public NoEventTransitionSet value() {
        return this;
    }

    @Override
    public List<NoEventTransition> elements() {
        return Arrays.asList(toArray(new NoEventTransition[0]));
    }

}
